@@ -6,7 +6,5 @@ class Configuration(object):
         self.current = default
 
     def loadFromFile(self, fn):
-        with f as open(fn):
+        with open(fn) as f:
             return json.loads(fn.read())
-            
-            
